# Verity AI Python Client
Comprehensive API service for unstructured and structured RAG generation, file management, UI interactions, ground truth generation, and evaluation

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 0.1.0
- Generator version: 7.13.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import verity_ai_pyc
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import verity_ai_pyc
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import verity_ai_pyc
from verity_ai_pyc.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://chat.veritylabs.ai
# See configuration.py for a list of all supported configuration parameters.
configuration = verity_ai_pyc.Configuration(
    host = "https://chat.veritylabs.ai"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: XAPIKeyAuth
configuration.api_key['XAPIKeyAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['XAPIKeyAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with verity_ai_pyc.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = verity_ai_pyc.AgentsApi(api_client)
    agent_create_public = verity_ai_pyc.AgentCreatePublic() # AgentCreatePublic | 

    try:
        # Create a new agent
        api_response = api_instance.create_agent_endpoint_v1_agents_post(agent_create_public)
        print("The response of AgentsApi->create_agent_endpoint_v1_agents_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AgentsApi->create_agent_endpoint_v1_agents_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://chat.veritylabs.ai*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AgentsApi* | [**create_agent_endpoint_v1_agents_post**](docs/AgentsApi.md#create_agent_endpoint_v1_agents_post) | **POST** /services/v1/agents/ | Create a new agent
*AgentsApi* | [**delete_agent_endpoint_v1_agents_agent_id_delete**](docs/AgentsApi.md#delete_agent_endpoint_v1_agents_agent_id_delete) | **DELETE** /services/v1/agents/{agent_id} | Archive (soft-delete) an agent
*AgentsApi* | [**get_agent_endpoint_v1_agents_agent_id_get**](docs/AgentsApi.md#get_agent_endpoint_v1_agents_agent_id_get) | **GET** /services/v1/agents/{agent_id} | Get agent by ID
*AgentsApi* | [**list_agents_endpoint_v1_agents_get**](docs/AgentsApi.md#list_agents_endpoint_v1_agents_get) | **GET** /services/v1/agents/ | List all active agents
*AgentsApi* | [**update_agent_endpoint_v1_agents_agent_id_put**](docs/AgentsApi.md#update_agent_endpoint_v1_agents_agent_id_put) | **PUT** /services/v1/agents/{agent_id} | Update an existing agent
*CompletionsApi* | [**create_chat_completion_rag_generation_chat_completions_post**](docs/CompletionsApi.md#create_chat_completion_rag_generation_chat_completions_post) | **POST** /services/rag-generation/chat/completions | chat completions
*FileManagementApi* | [**delete_files_fileman_data_delete_delete**](docs/FileManagementApi.md#delete_files_fileman_data_delete_delete) | **DELETE** /services/fileman/data/delete | delete files
*FileManagementApi* | [**list_files_get_fileman_data_list_get**](docs/FileManagementApi.md#list_files_get_fileman_data_list_get) | **GET** /services/fileman/data/list | list files (GET method)
*FileManagementApi* | [**upload_file_fileman_data_upload_post**](docs/FileManagementApi.md#upload_file_fileman_data_upload_post) | **POST** /services/fileman/data/upload | upload files
*ModelsApi* | [**list_models_rag_generation_models_get**](docs/ModelsApi.md#list_models_rag_generation_models_get) | **GET** /services/rag-generation/models | List Models
*StructuredApi* | [**list_db_tables_unstructured**](docs/StructuredApi.md#list_db_tables_unstructured) | **GET** /services/rag-generation/db_tables | list db tables
*UnstructuredApi* | [**list_kb_documents**](docs/UnstructuredApi.md#list_kb_documents) | **GET** /services/rag-generation/kb_docs | list knowledge base documents
*UnstructuredApi* | [**retrieve**](docs/UnstructuredApi.md#retrieve) | **POST** /services/rag-generation/retrieve | retrieve unstructured data
*UnstructuredApi* | [**validate_ingestion_rag_generation_validate_ingestion_post**](docs/UnstructuredApi.md#validate_ingestion_rag_generation_validate_ingestion_post) | **POST** /services/rag-generation/validate_ingestion | Validate ingestion status of uploaded documents


## Documentation For Models

 - [AgentCreatePublic](docs/AgentCreatePublic.md)
 - [AgentResponse](docs/AgentResponse.md)
 - [AgentUpdatePublic](docs/AgentUpdatePublic.md)
 - [ChatCompletionMessage](docs/ChatCompletionMessage.md)
 - [ChatCompletionRequestPublic](docs/ChatCompletionRequestPublic.md)
 - [ChatCompletionResponse](docs/ChatCompletionResponse.md)
 - [CrawlerJobRequestPublic](docs/CrawlerJobRequestPublic.md)
 - [CrawlerJobResponse](docs/CrawlerJobResponse.md)
 - [CrawlerJobStatusResponse](docs/CrawlerJobStatusResponse.md)
 - [CreateSessionPayload](docs/CreateSessionPayload.md)
 - [DeleteRequest](docs/DeleteRequest.md)
 - [DeleteResponse](docs/DeleteResponse.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [FileInfo](docs/FileInfo.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [KnowledgeBase](docs/KnowledgeBase.md)
 - [KnowledgeBase1](docs/KnowledgeBase1.md)
 - [KnowledgeBase2](docs/KnowledgeBase2.md)
 - [ListFilesPagination](docs/ListFilesPagination.md)
 - [ListFilesResponse](docs/ListFilesResponse.md)
 - [Message](docs/Message.md)
 - [NextToken](docs/NextToken.md)
 - [RetrievalRequestPublic](docs/RetrievalRequestPublic.md)
 - [UploadFileResponse](docs/UploadFileResponse.md)
 - [Usage](docs/Usage.md)
 - [UserDetailsRequest](docs/UserDetailsRequest.md)
 - [ValidateDocsRequest](docs/ValidateDocsRequest.md)
 - [ValidateDocsResponse](docs/ValidateDocsResponse.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="XAPIKeyAuth"></a>
### XAPIKeyAuth

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header


## Author




